@@ -395,7 +395,10 @@ void PmTimeLive::setupAssistant()
 		    this, SLOT(assistantError(const QString &)));
     QStringList arguments;
     QString documents = HTMLDIR;
-    arguments << "-profile" << documents.append("/pmtime.adp");
+    QString separator = QString(__pmPathSeparator());
+    documents.append(separator).append("html");
+    documents.append(separator).append("pcpdoc.adp");
+    arguments << "-profile" << documents;
     my.assistant->setArguments(arguments);
 }
 
@@ -403,5 +406,8 @@ void PmTimeLive::helpManual()
 {
     setupAssistant();
     QString documents = HTMLDIR;
-    my.assistant->showPage(documents.append("/timecontrol.html"));
+    QString separator = QString(__pmPathSeparator());
+    documents.append(separator).append("html");
+    documents.append(separator).append("timecontrol.html");
+    my.assistant->showPage(documents);
 }
